kirlent_docutils is a set of tools
for generating impress.js and reveal.js presentations
from restructured text documents.

Since it aims to be compatible with any restructured text tool,
it doesn't define its own directives
and instead uses only standard `docutils`_ features.

At the moment, the tools are functional
but their usage and the slide markup might change.
This is also the reason why there is no documentation yet.
You can check out the files in the "examples" directory.

.. _docutils: https://docutils.sourceforge.io/
